# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.18.2~bb8d088',
    built_at='2025-05-08 07:46:14Z',
    sha='bb8d08850c5420f5f6b1be284d2d53846ff80c6d',
    branch='HEAD',
    tag='v4.18.2',
)
